window.Gleam.initSearch([{"doc":"gleamql","title":"gleamql","content":"# gleamql\n\n[![Package Version](https://img.shields.io/hexpm/v/gleamql)](https://hex.pm/packages/gleamql)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleamql/)\n\nA Simple Graphql Client Written In Gleam ✨\n\n## Usage\n\n```gleam\nimport gleamql\nimport gleam/json.{string}\nimport gleam/dynamic.{field}\nimport gleam/option.{Some}\nimport gleam/hackney\n\npub type Data {\n  Data(country: Country)\n}\n\npub type Country {\n  Country(name: String)\n}\n\nconst country_query = &quot;query CountryQuery($code: ID!) {\n  country(code: $code) {\n    name\n  }\n}&quot;\n\npub fn main() {\n  let assert Ok(Some(Data(country: Country(name: &quot;United Kingdom&quot;)))) =\n    gleamql.new()\n    |&gt; gleamql.set_query(country_query)\n    |&gt; gleamql.set_variable(&quot;code&quot;, json.string(&quot;GB&quot;))\n    |&gt; gleamql.set_host(&quot;countries.trevorblades.com&quot;)\n    |&gt; gleamql.set_path(&quot;/graphql&quot;)\n    |&gt; gleamql.set_header(&quot;Content-Type&quot;, &quot;application/json&quot;)\n    |&gt; gleamql.set_decoder(dynamic.decode1(\n      Data,\n      field(&quot;country&quot;, of: dynamic.decode1(Country, field(&quot;name&quot;, of: string))),\n    ))\n    |&gt; gleamql.send(hackney.send)\n}\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add gleamql\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/gleamql&gt;.\n","url":"index.html"},{"doc":"gleamql","title":"GraphQLError","content":"pub type GraphQLError {\n  ErrorMessage(message: String)\n  UnexpectedStatus(status: Int)\n  UnrecognisedResponse(response: String)\n  UnknownError(inner: Dynamic)\n}\n GleamQL Error\n\nErrorMessage(message: String)\n\n\nUnexpectedStatus(status: Int)\n\n\nUnrecognisedResponse(response: String)\n\n\nUnknownError(inner: Dynamic)\n\n\nSynonyms:\ngleamql.GraphQLError\ngleamql GraphQLError","url":"gleamql.html#GraphQLError"},{"doc":"gleamql","title":"Request","content":"pub type Request(t) {\n  Request(\n    http_request: request.Request(String),\n    query: Option(String),\n    variables: Option(List(#(String, Json))),\n    decoder: Option(Decoder(t)),\n  )\n}\n GleamQL Request\n\nRequest(\n  http_request: request.Request(String),\n  query: Option(String),\n  variables: Option(List(#(String, Json))),\n  decoder: Option(Decoder(t)),\n)\n\n\nSynonyms:\ngleamql.Request\ngleamql Request","url":"gleamql.html#Request"},{"doc":"gleamql","title":"new","content":"pub fn new() -&gt; Request(a)\n Construct a GleamQL Request\n\n Use with set functions to customise.\n\nSynonyms:\ngleamql.new\ngleamql new","url":"gleamql.html#new"},{"doc":"gleamql","title":"send","content":"pub fn send(\n  req: Request(a),\n  send: fn(gleam/http/request.Request(String)) -&gt;\n    Result(Response(String), b),\n) -&gt; Result(Option(a), GraphQLError)\n Send the built request to a GraphQL server.\n\n A HTTP client is needed to send the request, see https://github.com/gleam-lang/http#client-adapters.\n\nSynonyms:\ngleamql.send\ngleamql send","url":"gleamql.html#send"},{"doc":"gleamql","title":"set_decoder","content":"pub fn set_decoder(\n  req: Request(a),\n  decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Request(a)\n Set the decoder that will be used to deserialize the graphql response.\n\n If not given, the response will not be deserialized.\n\n \n gleamql.set_decoder(dynamic.decode1(\n   Data,\n   field(&quot;country&quot;, of: dynamic.decode1(Country, field(&quot;name&quot;, of: string))),\n ))\n \n\nSynonyms:\ngleamql.set_decoder\ngleamql set_decoder","url":"gleamql.html#set_decoder"},{"doc":"gleamql","title":"set_header","content":"pub fn set_header(\n  req: Request(a),\n  key: String,\n  value: String,\n) -&gt; Request(a)\n Set the header with the given value under the given header key.\n\n If already present, it is replaced.\n\n \n gleamql.set_header(&quot;Content-Type&quot;, &quot;application/json&quot;)\n \n\nSynonyms:\ngleamql.set_header\ngleamql set_header","url":"gleamql.html#set_header"},{"doc":"gleamql","title":"set_host","content":"pub fn set_host(req: Request(a), host: String) -&gt; Request(a)\n Set the host of the request.\n\n \n gleamql.set_host(&quot;countries.trevorblades.com&quot;)\n \n\nSynonyms:\ngleamql.set_host\ngleamql set_host","url":"gleamql.html#set_host"},{"doc":"gleamql","title":"set_path","content":"pub fn set_path(req: Request(a), path: String) -&gt; Request(a)\n Set the path of the request.\n\n \n gleamql.set_path(&quot;/graphql&quot;)\n \n\nSynonyms:\ngleamql.set_path\ngleamql set_path","url":"gleamql.html#set_path"},{"doc":"gleamql","title":"set_query","content":"pub fn set_query(req: Request(a), query: String) -&gt; Request(a)\n Set the query of the request\n\nSynonyms:\ngleamql.set_query\ngleamql set_query","url":"gleamql.html#set_query"},{"doc":"gleamql","title":"set_variable","content":"pub fn set_variable(\n  req: Request(a),\n  key: String,\n  value: Json,\n) -&gt; Request(a)\n Set a variable that is needed in the request query\n\n \n gleamql.set_variable(&quot;code&quot;, json.string(&quot;GB&quot;))\n \n\nSynonyms:\ngleamql.set_variable\ngleamql set_variable","url":"gleamql.html#set_variable"},{"doc":"gleamql","title":"gleamql","content":" Query a GraphQL server with `gleamql`.\n\n ```gleam\n gleamql.new()\n |&gt; gleamql.set_query(country_query)\n |&gt; gleamql.set_variable(&quot;code&quot;, json.string(&quot;GB&quot;))\n |&gt; gleamql.set_host(&quot;countries.trevorblades.com&quot;)\n |&gt; gleamql.set_path(&quot;/graphql&quot;)\n |&gt; gleamql.set_header(&quot;Content-Type&quot;, &quot;application/json&quot;)\n |&gt; gleamql.set_decoder(dynamic.decode1(\n   Data,\n   field(&quot;country&quot;, of: dynamic.decode1(Country, field(&quot;name&quot;, of: string))),\n ))\n |&gt; gleamql.send(hackney.send)\n ```\n","url":"gleamql.html"}]);